Method: Thor::Shell::Basic#ask

Defined in:
lib/vendor/thor/lib/thor/shell/basic.rb

#ask(statement, *args) ⇒ Object

Asks something to the user and receives a response.

If asked to limit the correct responses, you can pass in an array of acceptable answers. If one of those is not supplied, they will be shown a message stating that one of those answers must be given and re-asked the question.

If asking for sensitive information, the :echo option can be set to false to mask user input from $stdin.

Example

ask(“What is your name?”)

ask(“What is your favorite Neopolitan flavor?”, :limited_to => [“strawberry”, “chocolate”, “vanilla”])

ask(“What is your password?”, :echo => false)



54
55
56
57
58
59
60
61
62
63
# File 'lib/vendor/thor/lib/thor/shell/basic.rb', line 54

def ask(statement, *args)
  options = args.last.is_a?(Hash) ? args.pop : {}
  color = args.first

  if options[:limited_to]
    ask_filtered(statement, color, options)
  else
    ask_simply(statement, color, options)
  end
end